import org.apache.lucene.analysis.standard.StandardAnalyzer
import org.apache.lucene.document.Document
import org.apache.lucene.document.Field
import org.apache.lucene.index.IndexWriter

def writer = new IndexWriter(new File("index"), new StandardAnalyzer(), true)

new File("UnicodeData.txt").eachLine { line ->
    def ucharFields = line.split(';', 15)
    if (ucharFields[0].length() == 4) {
        def doc = new Document()
        doc.add(Field.Keyword("code", ucharFields[0]))
        doc.add(Field.Text("name", ucharFields[1]))
        doc.add(Field.Keyword("category", ucharFields[2]))
        doc.add(Field.Keyword("clazz", ucharFields[3]))
        doc.add(Field.Keyword("bidi", ucharFields[4]))
        doc.add(Field.Keyword("decomposition", ucharFields[5]))
        doc.add(Field.Keyword("numeric", ucharFields[8]))
        doc.add(Field.Keyword("mirrored", ucharFields[9]))
        doc.add(Field.Keyword("uppercase", ucharFields[12]))
        doc.add(Field.Keyword("lowercase", ucharFields[13]))
        doc.add(Field.Keyword("titlecase", ucharFields[14]))
        writer.addDocument(doc)
    }
}

writer.optimize()
writer.close()

//  0: Code value
//  1: Character name
//  2: General Category
//  3: Canonical Combining Classes
//  4: Bidirectional Category
//  5: Character Decomposition Mapping
//  6: Decimal digit value
//  7: Digit value
//  8: Numeric value
//  9: Mirrored
// 10: Unicode 1.0 Name
// 11: 10646 comment field
// 12: Uppercase Mapping
// 13: Lowercase Mapping 
// 14: Titlecase Mapping